@@ -35,6 +35,8 @@ def notification(request):
         msg = 'Missing SOAPACTION header.'
         log.error(msg)
         return HttpResponseBadRequest(msg)
+    else:
+        action = action.strip('"')
 
     try:
         notification_type = action.split('/')[-1]
